import { myRequest } from '@/util/api.js'


//客户列表
export function netKehuList(data) {
	return myRequest('customer/getList',data)
}

//创建客户
export function netAddkehu(data) {
	return myRequest('customer/addCustomer',data)
}

//筛选条件
export function netSelect() {
	return myRequest('common/selectOption')
}
//客户 筛选条件  归属人
export function netSearchStaffList(data) {
	return myRequest('customer/getSearchStaffList',data)
}

//上级 客户列表 筛选
export function netPrevCustomer(data) {
	return myRequest('customer/getSelectList',data)
}
//根据 客户  筛选联系人  customer_id
export function netLianxiren(data) {
	return myRequest('contacts/getSelectList',data)
}
//合同   筛选列表
export function netSelectContract(data) {
	return myRequest('contract/getSelectList',data)
}

//客户名称查重
export function netCheckName(data) {
	return myRequest('customer/selectName',data)
}

//创建 跟进 记录
export function netAddFollowRecords(data) {
	return myRequest('record/createRecord',data)
}

//处理 跟进记录
export function netContinueIsFollow(data) {
	return myRequest('record/record_add',data)
}

//跟进 记录 详情
export function netFollowRecordDetail(data) {
	return myRequest('record/getRecordDetail',data)
}

//跟进 记录  添加评论
export function netAddComment(data) {
	return myRequest('record/addComment',data)
}

//获取  评论 列表
export function netGetCommentList(data) {
	return myRequest('record/commentList',data)
}

//员工 列表
export function netStaffList(data) {
	return myRequest('common/getSelectStaff',data)
}

//获取客户 详情
export function netKehuDetail(data) {
	return myRequest('customer/customerDetail',data)
}

//获取客户  跟进记录    线索动态
export function netKehuFollow(data) {
	return myRequest('record/getList',data)
}
//待跟进客户
export function daibanKehuFollow(data) {
	return myRequest('record/getcustomerList',data)
}
//新增联系人
export function netAddLianxiren(data) {
	return myRequest('contacts/addContacts',data)
}
//创建合同
export function netCreateContract(data) {
	return myRequest('contract/addContract',data)
}
//合同编号
export function netContractNum() {
	return myRequest('contract/getContractNumber')
}
//移入 公海
export function netRemoveSeas(data) {
	return myRequest('customer/moveSeas',data)
}
//领取客户
export function netReceiveKehu(data) {
	return myRequest('customer/receive',data)
}
//转移 客户
export function netTransKehu(data) {
	return myRequest('customer/transfer',data)
}
//重点关注
export function netKeyCollect(data) {
	return myRequest('customer/collect',data)
}
//取消重点 关注
export function netRemoveColect(data) {
	return myRequest('customer/cancelCollect',data)
}
//编辑 客户信息
export function netEditKehu(data) {
	return myRequest('customer/editCustomer',data)
}

//联系人列表
export function netContactList(data) {
	return myRequest('contacts/getList',data)
}

//详情 联系人列表
export function netContact(data) {
	return myRequest('contacts/getSelectList',data)
}
//获取 客户 合同  列表
export function netContractList(data) {
	return myRequest('contract/getCustomerContacts',data)
}

//获取 客户  相关信息  附件列表
export function netKehuFileList(data) {
	return myRequest('customer/getFilesList',data)
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////
//获取联系人  详情
export function netConcatDetailInfo(data) {
	return myRequest('contacts/getDetail',data)
}
//获取联系人  附件
export function netContactFileList(data) {
	return myRequest('contacts/getFilesList',data)
}
//获取 操作记录  1客户  2联系人   3合同
export function netOperationList(data) {
	return myRequest('operation/getList',data)
}
//编辑 联系人  信息
export function netEditContactInfo(data) {
	return myRequest('contacts/editContacts',data)
}
//删除 联系人
export function netDelContact(data) {
	return myRequest('contacts/delContacts',data)
}
//编辑 附件  名称
export function netEditFileName(data) {
	return myRequest('file/editName',data)
}


///////////////////////////////////////////////////////////////////////////////////////////////////////
//合同详情
export function netContractDetail(data) {
	return myRequest('contract/getDetail',data)
}
//回款计划  列表 
export function netPlanListf(data) {
	return myRequest('receivables_plan/getList',data)
}
//创建 回款  计划 
export function netAddPlan(data) {
	return myRequest('receivables_plan/addPlan',data)
}
//获取  回款  期数
export function netPaymentNum(data) {
	return myRequest('receivables_plan/getSelectList',data)
}
//创建   回款 
export function netAddPayment(data) {
	return myRequest('receivables/addReceivables',data)
}
//回款 列表 回款记录 列表
export function netPaymentList(data) {
	return myRequest('receivables/getList',data)
}
//回款编号
export function netPaymentNumber() {
	return myRequest('receivables/getReceivablesNumber')
}
//获取  回款  详情
export function netPaymentDetail(data) {
	return myRequest('receivables/getDetail',data)
}
//获取  回款  审批  流程    relation_type receivables 回款 contract 合同 consume 费用
export function netPaymentApproval(data) {
	return myRequest('examine_record/getList',data)
}
//获取 合同 附件
export function netContractFileList(data) {
	return myRequest('contract/getFilesList',data)
}

//审核  relation_type receivables 回款 contract 合同 consume 费用
export function netExamine(data) {
	return myRequest('examine_record/examine',data)
}

//合同   撤回 审批
export function netCancelExamine(data) {
	return myRequest('contract/cancel',data)
}
//编辑  合同
export function netEditContract(data) {
	return myRequest('contract/editContract',data)
}

//  回款  撤回  审批
export function netPaymentCancel(data) {
	return myRequest('receivables/cancel',data)
}
//编辑  回款  信息
export function netEditPaymentInfo(data) {
	return myRequest('receivables/editReceivables',data)
}

//CRM 合同 列表 
export function netCrmContractList(data) {
	return myRequest('contract/getList',data)
}

//添加 合同时  获取购买产品
export function netContractProduct(data) {
	return myRequest('product/getSelectList',data)
}

//产品分类
export function netProductTypeList(data) {
	return myRequest('product/getTypeList', data)
}
 
 //获取产品分类
 export function netProductClass(data) {
	 return myRequest('product/getProducttypeList',data)
 }
 
 //产品详情
 export function netProductDetail(data) {
	 return myRequest('product/getProductDetail',data)
 }

///////////////////////////////////////////////////////////////////////////////////////////////////
//新建 费用
export function netAddCost(data) {
	return myRequest('consume/addConsume',data)
}
//费用 列表
export function netCostList(data) {
	return myRequest('consume/getList',data)
}
//费用 详情
export function netCostDetail(data) {
	return myRequest('consume/getDetail',data)
}

//编辑  费用 
export function netEditCost(data) {
	return myRequest('consume/editConsume',data)
}

/////////////////////////////////////////////////////////////////////////////////////
//下级  客户  列表
export function netSubordList(data) {
	return myRequest('customer/getLowerCustomer',data)
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////
//当月 数据  简报
export function netGetBriefdata(data) {
	return myRequest('index/briefing',data)
}
//交易额  排行
export function netTurnoverList(data) {
	return myRequest('index/contractRanding',data)
}
/////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
//实际 回款 数据 
//身份为 员工时  获取 回款 列表
export function netGetreceivableStaff(){
	return myRequest('statistics/receivablesStatistics')
}
//身份  为其他时  获取 回款  列表
export function netGetOthersReceivable() {
	return myRequest('statistics/staffReceivablesStatistics')
}

///////////////////////////////////////////////////////////////////////////////
//业绩 目标
//获取 部门  年  筛选条件
export function netGetTargetSelect() {
	return myRequest('achievement/getDepartment')
}

//获取 成员列表 目标  列表
export function netGetDepTargetlist(data) {
	return myRequest('achievement/getStaffList',data)
}

//获取  成员 默认目标详情
export function netGetDefaultSelfDetail(data){
	return myRequest('achievement/getMyAchievementDetail',data)
}

//修改  我的  业绩目标
export function netSetMymubiao(data){
	return myRequest('achievement/staffEditAchievement',data)
}

//我的  业绩目标  修改记录
export function netGetRecordList(data) {
	return myRequest('achievement/editRecords',data)
}

//修改  记录  修改  详情
export function netGetRecordDetail(data) {
	return myRequest('achievement/getRecordsDetail',data)
}

//获取 部门 列表
export function netGetBumenList(data) {
	return myRequest('achievement/getDepartmentList',data)
}

//获取 团队 列表
export function netGetTealList(data) {
	return myRequest('achievement/getTeamList',data)
}

//获取  公司 列表
export function netGetGongsiList(data) {
	return myRequest('achievement/getCompanyAchievement',data)
}

//设置 目标  金额
export function netSetTargetMoney(data) {
	return myRequest('achievement/addAchievement',data)
}

//获取 默认  目标  金额
export function netGetDefaultMoney(data) {
	return myRequest('achievement/getAchievementDetail',data)
}

//CRM  全局搜索
export function netQueryData(data) {
	return myRequest('index/search',data)
}







